summaryrefslogtreecommitdiffstats
path: root/include/http_log.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/http_log.h')
-rw-r--r--include/http_log.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/http_log.h b/include/http_log.h
index cced5cc67d..e82389bece 100644
--- a/include/http_log.h
+++ b/include/http_log.h
@@ -741,11 +741,11 @@ AP_DECLARE(void) ap_error_log2stderr(server_rec *s);
AP_DECLARE(void) ap_log_command_line(apr_pool_t *p, server_rec *s);
/**
* Log common shared data
* @param s The server_rec whose process's command line we want to log.
* Misc commonly logged data is logged to that server's error log.
*/
-AP_DECLARE(void) ap_log_common(server_rec *s);
+AP_DECLARE(void) ap_log_mpm_common(server_rec *s);
/**
* Log the current pid of the parent process
@@ -741,11 +741,11 @@ AP_DECLARE(void) ap_error_log2stderr(server_rec *s);
AP_DECLARE(void) ap_log_command_line(apr_pool_t *p, server_rec *s);
/**
- * Log common shared data
- * @param s The server_rec whose process's command line we want to log.
+ * Log common (various) MPM shared data at startup.
+ * @param s The server_rec of the error log we want to log to.
* Misc commonly logged data is logged to that server's error log.
*/